@@ -2,7 +2,7 @@ use strict;
 use warnings;
 use Dist::Iller::Standard;
 
-our $VERSION = '0.1203'; # VERSION
+our $VERSION = '0.1204'; # VERSION
 # PODNAME: Dist::Iller::Role::Config
 
 role Dist::Iller::Role::Config using Moose {
@@ -13,9 +13,15 @@ role Dist::Iller::Role::Config using Moose {
         is => 'ro',
         isa => Str,
     );
+    has main_module => (
+        is => 'ro',
+        isa => Str,
+        predicate => 1,
+        documentation => q{Override this attribute when there's more than one config in a distribution. It uses the main_module's sharedir location for the config files.},
+    );
 
     method configlocation {
-        my $package = $self->meta->name;
+        my $package = $self->has_main_module ? $self->main_module : $self->meta->name;
         $package =~ s{::}{-}g;
         my $dir = path('.');
         try {
@@ -59,7 +65,7 @@ Dist::Iller::Role::Config
 
 =head1 VERSION
 
-Version 0.1203, released 2016-01-09.
+Version 0.1204, released 2016-01-22.
 
 =head1 SOURCE
 
